@@ -16,12 +16,12 @@
 #include "RangeGroup.h"
 #include "datasource/ChartDataSource.h"
 #include "scenegraph/LineChartNode.h"
-#include "scenegraph/LineGridNode.h"
 
 static const float PixelsPerStep = 2.0;
 
-QVector<QVector2D> interpolate(const QVector<QVector2D> &points, float height);
-QVector<float> calculateTangents(const QVector<QVector2D> &points, float height);
+
+QList<QVector2D> interpolatePoints(const QList<QVector2D> &points, float height);
+QList<float> calculateTangents(const QList<QVector2D> &points, float height);
 QVector2D cubicHermite(const QVector2D &first, const QVector2D &second, float step, float mFirst, float mSecond);
 
 QColor colorWithAlpha(const QColor &color, qreal opacity)
@@ -108,9 +108,9 @@ LineChart::LineChart(QQuickItem *parent)
 {
 }
 
-bool LineChart::smooth() const
+bool LineChart::interpolate() const
 {
-    return m_smooth;
+    return m_interpolate;
 }
 
 qreal LineChart::lineWidth() const
@@ -123,15 +123,15 @@ qreal LineChart::fillOpacity() const
     return m_fillOpacity;
 }
 
-void LineChart::setSmooth(bool smooth)
+void LineChart::setInterpolate(bool newInterpolate)
 {
-    if (smooth == m_smooth) {
+    if (newInterpolate == m_interpolate) {
         return;
     }
 
-    m_smooth = smooth;
+    m_interpolate = newInterpolate;
     polish();
-    Q_EMIT smoothChanged();
+    Q_EMIT interpolateChanged();
 }
 
 void LineChart::setLineWidth(qreal width)
@@ -184,7 +184,7 @@ void LineChart::setPointDelegate(QQmlComponent *newPointDelegate)
     }
 
     m_pointDelegate = newPointDelegate;
-    for (auto entry : qAsConst(m_pointDelegates)) {
+    for (auto entry : std::as_const(m_pointDelegates)) {
         qDeleteAll(entry);
     }
     m_pointDelegates.clear();
@@ -199,7 +199,7 @@ void LineChart::updatePolish()
         m_rangeInvalid = false;
     }
 
-    QVector<QVector2D> previousValues;
+    QList<QVector2D> previousValues;
 
     const auto range = computedRange();
     const auto sources = valueSources();
@@ -207,7 +207,7 @@ void LineChart::updatePolish()
         auto valueSource = sources.at(i);
 
         float stepSize = width() / (range.distanceX - 1);
-        QVector<QVector2D> values(range.distanceX);
+        QList<QVector2D> values(range.distanceX);
         auto generator = [&, i = range.startX]() mutable -> QVector2D {
             float value = 0;
             if (range.distanceY != 0) {
@@ -250,8 +250,8 @@ void LineChart::updatePolish()
             }
         }
 
-        if (m_smooth) {
-            m_values[valueSource] = interpolate(values, height());
+        if (m_interpolate) {
+            m_values[valueSource] = interpolatePoints(values, height());
         } else {
             m_values[valueSource] = values;
         }
@@ -305,10 +305,9 @@ void LineChart::onDataChanged()
     polish();
 }
 
-void LineChart::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+void LineChart::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
 {
-    XYChart::geometryChanged(newGeometry, oldGeometry);
-
+    XYChart::geometryChange(newGeometry, oldGeometry);
     if (newGeometry != oldGeometry) {
         polish();
     }
@@ -331,11 +330,11 @@ void LineChart::updateLineNode(LineChartNode *node, const QColor &lineColor, con
     node->updatePoints();
 }
 
-void LineChart::createPointDelegates(const QVector<QVector2D> &values, int sourceIndex)
+void LineChart::createPointDelegates(const QList<QVector2D> &values, int sourceIndex)
 {
     auto valueSource = valueSources().at(sourceIndex);
 
-    QVector<QQuickItem *> delegates;
+    QList<QQuickItem *> delegates;
     for (int i = 0; i < values.size(); ++i) {
         auto delegate = qobject_cast<QQuickItem *>(m_pointDelegate->beginCreate(qmlContext(m_pointDelegate)));
         if (!delegate) {
@@ -369,7 +368,7 @@ void LineChart::updatePointDelegate(QQuickItem *delegate, const QVector2D &posit
 }
 
 // Smoothly interpolate between points, using monotonic cubic interpolation.
-QVector<QVector2D> interpolate(const QVector<QVector2D> &points, float height)
+QList<QVector2D> interpolatePoints(const QList<QVector2D> &points, float height)
 {
     if (points.size() < 2) {
         return points;
@@ -377,7 +376,7 @@ QVector<QVector2D> interpolate(const QVector<QVector2D> &points, float height)
 
     auto tangents = calculateTangents(points, height);
 
-    QVector<QVector2D> result;
+    QList<QVector2D> result;
 
     auto current = QVector2D{0.0, points.first().y() * height};
     result.append(QVector2D{0.0, points.first().y()});
@@ -414,12 +413,12 @@ QVector<QVector2D> interpolate(const QVector<QVector2D> &points, float height)
 
 // This calculates the tangents for monotonic cubic spline interpolation.
 // See https://en.wikipedia.org/wiki/Monotone_cubic_interpolation for details.
-QVector<float> calculateTangents(const QVector<QVector2D> &points, float height)
+QList<float> calculateTangents(const QList<QVector2D> &points, float height)
 {
-    QVector<float> secantSlopes;
+    QList<float> secantSlopes;
     secantSlopes.reserve(points.size());
 
-    QVector<float> tangents;
+    QList<float> tangents;
     tangents.reserve(points.size());
 
     float previousSlope = 0.0;
@@ -498,3 +497,5 @@ QVector2D cubicHermite(const QVector2D &first, const QVector2D &second, float st
     auto result = QVector2D{step, first.y() * h00 + delta * mFirst * h10 + second.y() * h01 + delta * mSecond * h11};
     return result;
 }
+
+#include "moc_LineChart.cpp"
